@@ -1,5 +1,5 @@
 /*
- * @source: https://github.com/validator/validator/blob/master/site/nu-script.js
+ * @source: https://github.com/validator/validator/blob/main/site/nu-script.js
  *
  * @licstart  The following is the entire license notice for the JavaScript
  * code in this file.
@@ -270,6 +270,13 @@ function createHtmlElement(tagName) {
 function injectHyperlinks() {
 	var errors = document.getElementsByClassName("error")
 	var warnings = document.getElementsByClassName("warning")
+	var info = document.getElementsByClassName("info")
+	linkify(info, "has no effect",
+		"https://github.com/validator/validator/wiki/Markup-%C2%BB-Void-elements#trailing-slashes-in-void-element-start-tags-do-not-mark-the-start-tags-as-self-closing",
+		"Trailing slashes in void-element start tags do not mark the start tags as self-closing")
+	linkify(info, "interacts badly with unquoted attribute values",
+		"https://github.com/validator/validator/wiki/Markup-%C2%BB-Void-elements#trailing-slashes-directly-preceded-by-unquoted-attribute-values",
+		"Trailing slashes directly preceded by unquoted attribute values")
 	linkify(warnings, "file an issue report",
 		"https://github.com/validator/validator/issues/new",
 		"File a report in the GitHub issue tracker.")
@@ -277,7 +284,7 @@ function injectHyperlinks() {
 		"about.html#rdfa",
 		"About HTML5 + RDFa 1.1 checking.")
 	linkify(warnings, "are treated as top-level headings by many screen readers and other tools",
-		"https://www.w3.org/wiki/HTML/Usage/Headings/h1only",
+		"https://html5accessibility.com/stuff/2021/07/08/preserved-in-html/",
 		"HTML heading usage and tools support")
 	linkify(warnings, "add identifying headings to all sections",
 		"https://www.w3.org/wiki/HTML/Usage/Headings/Missing",
@@ -349,8 +356,8 @@ function moveLangAndDirWarningsAndAddLinks() {
 	var langOrDirWarningText = "This document appears to be written in"
 	var undetectedMissingLang= "Consider adding a lang attribute"
 	var contentLanguageText = "The value of the HTTP Content-Language header is"
-	var langTextWithNoLangGuidance = 'For further guidance, consult <a href="https://www.w3.org/International/questions/qa-no-language#nonlinguistic">Tagging text with no language</a>, <a href="https://www.w3.org/International/techniques/authoring-html#textprocessing">Declaring the overall language of a page</a> and <a href="https://www.w3.org/International/techniques/authoring-html#langvalues">Choosing language tags</a>.'
-	var langGuidance = 'For further guidance, consult <a href="https://www.w3.org/International/techniques/authoring-html#textprocessing">Declaring the overall language of a page</a> and <a href="https://www.w3.org/International/techniques/authoring-html#langvalues">Choosing language tags</a>.'
+	var langTextWithNoLangGuidance = 'For further guidance, consult <a href="https://www.w3.org/International/questions/qa-no-language#nonlinguistic">Tagging text with no language</a>, <a href="https://www.w3.org/International/techniques/authoring-html.en?open=language&open=textprocessing#textprocessing">Declaring the overall language of a page</a> and <a href="https://www.w3.org/International/techniques/authoring-html.en?open=language&open=langvalues#langvalues">Choosing language tags</a>.'
+	var langGuidance = 'For further guidance, consult <a href="https://www.w3.org/International/techniques/authoring-html.en?open=language&open=textprocessing#textprocessing">Declaring the overall language of a page</a> and <a href="https://www.w3.org/International/techniques/authoring-html.en?open=language&open=langvalues#langvalues">Choosing language tags</a>.'
 	var contentLangGuidance = 'For further guidance, consult <a href="https://www.w3.org/International/questions/qa-http-and-lang">HTTP headers, meta elements and language information</a>.'
 	var dirGuidance = 'For further guidance, consult <a href="https://www.w3.org/International/questions/qa-html-dir">Structural markup and right-to-left text in HTML</a> and <a href="https://www.w3.org/International/techniques/authoring-html#using">Setting up a right-to-left page</a>.'
 	var ifMisidentifiedGuidance = 'If the HTML checker has misidentified the language of this document, please <a href="https://github.com/validator/validator/issues/new">file an issue report</a> or <a href="mailto:www-validator@w3.org">send e-mail to report the problem</a>.'
@@ -584,7 +591,9 @@ if (document.getElementById) {
 				var helptext = document.querySelector("#filters > div")
 				if (filtersbutton) {
 					filtersbutton.className = "message_filtering"
-					filtersbutton.focus()
+					if (!window.location.hash) {
+						filtersbutton.focus()
+					}
 					filtersbutton.setAttribute('tabindex', '0')
 				}
 				if (helptext) {
